# limix-genetics

[![PyPIl](https://img.shields.io/pypi/l/limix-genetics.svg?style=flat-square)](https://pypi.python.org/pypi/limix-genetics/)
[![PyPIv](https://img.shields.io/pypi/v/limix-genetics.svg?style=flat-square)](https://pypi.python.org/pypi/limix-genetics/)
[![Documentation Status](https://readthedocs.org/projects/limix-genetics/badge/?style=flat-square&version=latest)](https://limix-genetics.readthedocs.io/en/latest/)


Genetic-related tools for Limix.

## Install

The recommended way of installing it is via
[conda](http://conda.pydata.org/docs/index.html)
```bash
conda install -c conda-forge limix-genetics
```

An alternative way would be via pip
```bash
pip install limix-genetics
```

Refer to [documentation](http://limix-genetics.readthedocs.io/en/latest/)
for more information.

## Running the tests

After installation, you can test it
```
python -c "import limix_genetics; limix_genetics.test()"
```
as long as you have [pytest](http://docs.pytest.org/en/latest/).

## Authors

* **Danilo Horta** - [https://github.com/Horta](https://github.com/Horta)

## License

This project is licensed under the MIT License - see the
[LICENSE](LICENSE) file for details
